#!/usr/bin/env python2
# -*- coding: utf-8 -*-

# jp: a SàT command line tool
# Copyright (C) 2009-2016 Jérôme Poisson (goffi@goffi.org)

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


import base
from sat.core.i18n import _
from sat_frontends.jp.constants import Const as C
from functools import partial

__commands__ = ["Event"]


class Get(base.CommandBase):

    def __init__(self, host):
        base.CommandBase.__init__(self,
                                  host,
                                  'get',
                                  use_output=C.OUTPUT_DICT,
                                  use_pubsub_node_req=True,
                                  use_verbose=True,
                                  help=_(u'get event attendance'))
        self.need_loop=True

    def add_parser_options(self):
        pass

    def eventGetCb(self, event_data):
        self.output(event_data)
        self.host.quit()

    def start(self):
        self.host.bridge.eventGet(
            self.args.service,
            self.args.node,
            self.profile,
            callback=self.eventGetCb,
            errback=partial(self.errback,
                            msg=_(u"can't get event data: {}"),
                            exit_code=C.EXIT_BRIDGE_ERRBACK))


class Set(base.CommandBase):
    def __init__(self, host):
        super(Set, self).__init__(host, 'set', use_output=C.OUTPUT_DICT, use_pubsub_node_req=True, help=_('set event attendance'))
        self.need_loop=True

    def add_parser_options(self):
        self.parser.add_argument("-f", "--field", type=base.unicode_decoder, action='append', nargs=2, dest='fields',
                                 metavar=(u"KEY", u"VALUE"), help=_(u"configuration field to set"))

    def start(self):
        fields = dict(self.args.fields) if self.args.fields else {}
        self.host.bridge.eventSet(
            self.args.service,
            self.args.node,
            fields,
            self.profile,
            callback=self.host.quit,
            errback=partial(self.errback,
                            msg=_(u"can't set event data: {}"),
                            exit_code=C.EXIT_BRIDGE_ERRBACK))


class Event(base.CommandBase):
    subcommands = (Get, Set)

    def __init__(self, host):
        super(Event, self).__init__(host, 'event', use_profile=False, help=_('event management'))
